local addonName, L = ...;

-- Create new Handler:
local TeamCache = ArenaLiveCore:AddHandler("TeamCache");

-- Local reference to the saved variable table containing the teams.
local teamDB;

-- Global for StaticPopupDialog
ALSPEC_TEAM_CACHE_CURRENT_TEAM = nil;

function TeamCache:Initialise()
	 teamDB = ArenaLiveCore:GetDBEntry(addonName, "TeamCache")
end

-- Update function for already existing Teams:
local updateName, updateTag, updateIcon, updateMember1, updateMember2, updateMember3;
function TeamCache:UpdateTeam()

	if ( not updateName or not teamDB[updateName] ) then
		--TODO: Error
		return;
	end

	teamDB[updateName]["Tag"] = updateTag;
	teamDB[updateName]["Icon"] = updateIcon;
	teamDB[updateName]["Member1"] = updateMember1;
	teamDB[updateName]["Member2"] = updateMember2;
	teamDB[updateName]["Member3"] = updateMember3;
	
end

-- Save a new team or update an existing one:
function TeamCache:SetTeam(side)
	
	if ( not side ) then
		ArenaLiveCore:Message(L["TEAM_CACHE_SET_ERROR_NO_TEAM_SIDE_GIVEN"], "error");
		return;
	end
	
	local dbModifier = "Teams/"..side;
		
	local teamName = ArenaLiveCore:GetDBEntry(addonName, dbModifier.."/Name");
	local teamTag = ArenaLiveCore:GetDBEntry(addonName, dbModifier.."/Tag");
	local teamIcon = ArenaLiveCore:GetDBEntry(addonName, dbModifier.."/Icon");
	local member1 = ArenaLiveCore:GetDBEntry(addonName, dbModifier.."/Member1");
	local member2 = ArenaLiveCore:GetDBEntry(addonName, dbModifier.."/Member2");
	local member3 = ArenaLiveCore:GetDBEntry(addonName, dbModifier.."/Member3");	
	
	-- Check if the team's name already exists:
	if ( teamDB[teamName] ) then
		updateName = teamName;
		updateTag = teamTag;
		updateIcon = teamIcon;
		updateMember1 = member1;
		updateMember2 = member2;
		updateMember3 = member3;		
		
		ALSPEC_TEAM_CACHE_CURRENT_TEAM = updateName;
		StaticPopup_Show("ARENALIVESPECTATOR_CONFIRM_TEAM_UPDATE");
		
		return;
	end

	teamDB[teamName] = {};
	teamDB[teamName]["Tag"] = teamTag;
	teamDB[teamName]["Icon"] = teamIcon;
	teamDB[teamName]["Member1"] = member1;
	teamDB[teamName]["Member2"] = member2;
	teamDB[teamName]["Member3"] = member3;
end

function TeamCache:GetTeam(name)

	if ( not name ) then
		ArenaLiveCore:Message(L["TEAM_CACHE_GET_ERROR_NO_TEAM_NAME_GIVEN"], "error");
		return;
	end
	
	if ( not teamDB[name] ) then
		ArenaLiveCore:Message(string.format(L["TEAM_CACHE_GET_ERROR_TEAM_DOESNT_EXIST"], name), "error");
		return;
	end
	
	local tag = teamDB[name]["Tag"];
	local icon = teamDB[name]["Icon"];
	local member1 = teamDB[name]["Member1"];
	local member2 = teamDB[name]["Member2"];
	local member3 = teamDB[name]["Member3"];
	
	return name, tag, icon, member1, member2, member3;
end

local info = {};
local function TeamCacheDropDown_Refresh(dropdown)

	if ( not dropdown:IsVisible() ) then
		return;
	end

	for teamName, teamInfo in pairs(teamDB) do
		info.text = teamName;
		info.value = teamName;
		info.func = dropdown.func;

		UIDropDownMenu_AddButton(info);
	end

end

function TeamCache:InitialiseDropdown(dropdown, onClick, titleText)

	local prefix = dropdown:GetName();
	local title = _G[prefix.."Title"];
	
	if ( title ) then
		-- Set dropdown title
		title:SetText(titleText);
	end
	
	-- Set OnClick function for info buttons:
	dropdown.func = onClick;
	
	-- Set initial Text:
	UIDropDownMenu_SetText(dropdown, L["TEAM_CACHE_DROPDOWN_DEFAULT_TEXT"]);
	
	-- Initialise the dropdown using blizzard's standard functionset.
	UIDropDownMenu_Initialize(dropdown, TeamCacheDropDown_Refresh);

end

function TeamCache:SetDropDownTeamSide(dropdown, side)
	dropdown.currentTeam = side;
end

function TeamCache:DeleteTeam(name)

	if ( not name ) then
		ArenaLiveCore:Message(L["TEAM_CACHE_DELETE_ERROR_NO_TEAM_NAME_GIVEN"], "error");
		return;
	end
	
	if ( not teamDB[name] ) then
		ArenaLiveCore:Message(string.format(L["TEAM_CACHE_DELETE_ERROR_TEAM_DOESNT_EXIST"], name), "error");
		return;
	end

	teamDB[name] = nil;
end

function TeamCache:DeleteAll()
	for teamName, teamInfo in pairs(teamDB) do
		TeamCache:DeleteTeam(teamName);
	end
end